From: Michael R. Crusoe <michael.crusoe@gmail.com>
Subject: Add proper "#!" header to all CWL files
--- schema-salad.orig/schema_salad/tests/foreign/foreign_prop1.cwl
+++ schema-salad/schema_salad/tests/foreign/foreign_prop1.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 doc: |
   Foreign properties test.  This property is not part of the supplied
   ontology.  If strict_foreign_properties is true, it should fail.  If
@@ -7,4 +8,4 @@
 inputs: []
 outputs: []
 baseCommand: echo
-'edam:has_topic': abc
\ No newline at end of file
+'edam:has_topic': abc
--- schema-salad.orig/schema_salad/tests/foreign/foreign_prop2.cwl
+++ schema-salad/schema_salad/tests/foreign/foreign_prop2.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 doc: |
   Foreign properties test.  If strict_foreign_properties is true, it
   should fail.  If false, should pass no warnings.
@@ -8,4 +9,4 @@
 inputs: []
 outputs: []
 baseCommand: echo
-'edam:has_topic': abc
\ No newline at end of file
+'edam:has_topic': abc
--- schema-salad.orig/schema_salad/tests/foreign/foreign_prop3.cwl
+++ schema-salad/schema_salad/tests/foreign/foreign_prop3.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 doc: |
   Foreign properties test.  Should pass since the edam namespace is declared,
   the ontology is imported, the property is valid in the ontology, and the
@@ -11,4 +12,4 @@
 inputs: []
 outputs: []
 baseCommand: echo
-edam:has_topic: edam:topic_0003
\ No newline at end of file
+edam:has_topic: edam:topic_0003
--- schema-salad.orig/schema_salad/tests/foreign/foreign_prop4.cwl
+++ schema-salad/schema_salad/tests/foreign/foreign_prop4.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 doc: |
   Foreign properties test.  This property is not part of the supplied
   ontology.  If strict_foreign_properties is true, it should fail.  If
@@ -11,4 +12,4 @@
 inputs: []
 outputs: []
 baseCommand: echo
-'edam:fake_property': abc
\ No newline at end of file
+'edam:fake_property': abc
--- schema-salad.orig/schema_salad/tests/foreign/foreign_prop5.cwl
+++ schema-salad/schema_salad/tests/foreign/foreign_prop5.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 doc: |
   Foreign properties test.  The property is supposed to cross
   reference another concept node, but that node doesn't exist.
@@ -12,4 +13,4 @@
 inputs: []
 outputs: []
 baseCommand: echo
-edam:has_topic: abc
\ No newline at end of file
+edam:has_topic: abc
--- schema-salad.orig/schema_salad/tests/foreign/foreign_prop6.cwl
+++ schema-salad/schema_salad/tests/foreign/foreign_prop6.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 doc: |
   Foreign properties test.  The property
   references a mailto: URI
@@ -10,4 +11,4 @@
 inputs: []
 outputs: []
 baseCommand: echo
-edam:has_topic: mailto:test@example.com
\ No newline at end of file
+edam:has_topic: mailto:test@example.com
--- schema-salad.orig/schema_salad/tests/foreign/foreign_prop7.cwl
+++ schema-salad/schema_salad/tests/foreign/foreign_prop7.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 doc: |
   Foreign properties test.  The property
   reference an unsupported mailto: URI
@@ -10,4 +11,4 @@
 inputs: []
 outputs: []
 baseCommand: echo
-edam:has_topic: urn:blurb
\ No newline at end of file
+edam:has_topic: urn:blurb
--- schema-salad.orig/schema_salad/tests/test_schema/test1.cwl
+++ schema-salad/schema_salad/tests/test_schema/test1.cwl
@@ -1 +1,2 @@
-class: Workflow
\ No newline at end of file
+#!/usr/bin/env cwl-runner
+class: Workflow
--- schema-salad.orig/schema_salad/tests/test_schema/test10.cwl
+++ schema-salad/schema_salad/tests/test_schema/test10.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 class: Workflow
 inputs:
   foo: string
@@ -7,4 +8,4 @@
   step1:
     scatterMethod: [record]
     in: []
-    out: [out]
\ No newline at end of file
+    out: [out]
--- schema-salad.orig/schema_salad/tests/test_schema/test11.cwl
+++ schema-salad/schema_salad/tests/test_schema/test11.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 class: Workflow
 inputs:
   foo: string
@@ -7,4 +8,4 @@
   step1:
     run: blub.cwl
     in: []
-    out: [out]
\ No newline at end of file
+    out: [out]
--- schema-salad.orig/schema_salad/tests/test_schema/test12.cwl
+++ schema-salad/schema_salad/tests/test_schema/test12.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 cwlVersion: v1.0
 class: CommandLineTool
 baseCommand: echo
--- schema-salad.orig/schema_salad/tests/test_schema/test13.cwl
+++ schema-salad/schema_salad/tests/test_schema/test13.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 cwlVersion: v1.0
 class: Workflow
 inputs:
@@ -17,4 +18,4 @@
       id: blah
       class: CommandLineTool
       inputs: []
-      outputs: []
\ No newline at end of file
+      outputs: []
--- schema-salad.orig/schema_salad/tests/test_schema/test14.cwl
+++ schema-salad/schema_salad/tests/test_schema/test14.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 cwlVersion: v1.0
 class: CommandLineTool
 baseCommand: echo
--- schema-salad.orig/schema_salad/tests/test_schema/test16.cwl
+++ schema-salad/schema_salad/tests/test_schema/test16.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 cwlVersion: v1.0
 class: CommandLineTool
 baseCommand: echo
--- schema-salad.orig/schema_salad/tests/test_schema/test17.cwl
+++ schema-salad/schema_salad/tests/test_schema/test17.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 class: CommandLineTool
 cwlVersion: v1.0
 baseCommand: cowsay
--- schema-salad.orig/schema_salad/tests/test_schema/test18.cwl
+++ schema-salad/schema_salad/tests/test_schema/test18.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 class: CommandLineTool
 cwlVersion: v1.0
 baseCommand: echo
--- schema-salad.orig/schema_salad/tests/test_schema/test19.cwl
+++ schema-salad/schema_salad/tests/test_schema/test19.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 : aaa
 cwlVersion: v1.0
 class: CommandLineTool
--- schema-salad.orig/schema_salad/tests/test_schema/test2.cwl
+++ schema-salad/schema_salad/tests/test_schema/test2.cwl
@@ -1 +1,2 @@
-class: xWorkflow
\ No newline at end of file
+#!/usr/bin/env cwl-runner
+class: xWorkflow
--- schema-salad.orig/schema_salad/tests/test_schema/test3.cwl
+++ schema-salad/schema_salad/tests/test_schema/test3.cwl
@@ -1,6 +1,7 @@
+#!/usr/bin/env cwl-runner
 class: Workflow
 inputs:
   foo: string
 outputs:
   bar: xstring
-steps: []
\ No newline at end of file
+steps: []
--- schema-salad.orig/schema_salad/tests/test_schema/test4.cwl
+++ schema-salad/schema_salad/tests/test_schema/test4.cwl
@@ -1,6 +1,7 @@
+#!/usr/bin/env cwl-runner
 class: Workflow
 inputs:
   foo: string
 outputs:
   bar: 12
-steps: []
\ No newline at end of file
+steps: []
--- schema-salad.orig/schema_salad/tests/test_schema/test5.cwl
+++ schema-salad/schema_salad/tests/test_schema/test5.cwl
@@ -1,6 +1,7 @@
+#!/usr/bin/env cwl-runner
 class: Workflow
 inputs:
   foo: string
 outputs:
   bar: string
-steps: [12]
\ No newline at end of file
+steps: [12]
--- schema-salad.orig/schema_salad/tests/test_schema/test6.cwl
+++ schema-salad/schema_salad/tests/test_schema/test6.cwl
@@ -1,5 +1,6 @@
+#!/usr/bin/env cwl-runner
 inputs:
   foo: string
 outputs:
   bar: string
-steps: [12]
\ No newline at end of file
+steps: [12]
--- schema-salad.orig/schema_salad/tests/test_schema/test7.cwl
+++ schema-salad/schema_salad/tests/test_schema/test7.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 class: Workflow
 inputs:
   foo: string
@@ -7,4 +8,4 @@
   step1:
     scatter_method: blub
     in: []
-    out: [out]
\ No newline at end of file
+    out: [out]
--- schema-salad.orig/schema_salad/tests/test_schema/test8.cwl
+++ schema-salad/schema_salad/tests/test_schema/test8.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 class: Workflow
 inputs:
   foo: string
@@ -7,4 +8,4 @@
   step1:
     scatterMethod: abc
     in: []
-    out: [out]
\ No newline at end of file
+    out: [out]
--- schema-salad.orig/schema_salad/tests/test_schema/test9.cwl
+++ schema-salad/schema_salad/tests/test_schema/test9.cwl
@@ -1,3 +1,4 @@
+#!/usr/bin/env cwl-runner
 class: Workflow
 inputs:
   foo: string
@@ -7,4 +8,4 @@
   step1:
     scatterMethod: 12
     in: []
-    out: [out]
\ No newline at end of file
+    out: [out]
--- schema-salad.orig/schema_salad/tests/test_print_oneline.py
+++ schema-salad/schema_salad/tests/test_print_oneline.py
@@ -46,7 +46,7 @@
             except RuntimeError as e:
                 msg = reformat_yaml_exception_message(strip_dup_lineno(six.text_type(e)))
                 msg = to_one_line_messages(msg)
-                self.assertTrue(msg.endswith(src+":10:1: could not find expected \':\'"))
+                self.assertTrue(msg.endswith(src+":11:1: could not find expected \':\'"))
                 print("\n", e)
                 raise
 
@@ -62,10 +62,9 @@
                                   six.text_type(get_data("tests/test_schema/"+src)), True)
             except ValidationException as e:
                 msgs = to_one_line_messages(str(e)).splitlines()
-                self.assertEqual(len(msgs), 3)
-                self.assertTrue(msgs[0].endswith(src+":9:1: the `outputs` field is not valid because"))
-                self.assertTrue(msgs[1].endswith(src+":13:5: missing required field `id`"))
-                self.assertTrue(msgs[2].endswith(src+":13:5: invalid field `aa`, expected one of: 'label', 'secondaryFiles', 'format', 'streamable', 'doc', 'id', 'outputBinding', 'type'"))
+                assert len(msgs) == 2, msgs
+                self.assertTrue(msgs[0].endswith(src+":14:5: missing required field `id`"))
+                self.assertTrue(msgs[1].endswith(src+":14:5: invalid field `aa`, expected one of: 'label', 'secondaryFiles', 'format', 'streamable', 'doc', 'id', 'outputBinding', 'type'"))
                 print("\n", e)
                 raise
 
@@ -88,9 +87,9 @@
                 self.assertEqual(len(msgs), 2)
                 print("\n", e)
                 assert msgs[0].endswith(
-                    src + ':8:1: checking field `outputs`')
+                    src + ':9:1: checking field `outputs`')
                 assert msgs[1].endswith(
                     src + ':13:5: Field `type` references unknown identifier '
                     '`Filea`, tried file://%s#Filea' % (fullpath))
                 raise
 
@@ -108,8 +107,8 @@
                 msg = reformat_yaml_exception_message(strip_dup_lineno(six.text_type(e)))
                 msgs = msg.splitlines()
                 self.assertEqual(len(msgs), 2)
-                self.assertTrue(msgs[0].endswith(src+":9:7: while scanning a simple key"))
-                self.assertTrue(msgs[1].endswith(src+":10:1:   could not find expected ':'"))
+                self.assertTrue(msgs[0].endswith(src+":10:7: while scanning a simple key"))
+                self.assertTrue(msgs[1].endswith(src+":11:1:   could not find expected ':'"))
                 print("\n", e)
                 raise
 
@@ -125,7 +124,7 @@
                                   six.text_type(get_data("tests/test_schema/"+src)), True)
             except RuntimeError as e:
                 msg = reformat_yaml_exception_message(strip_dup_lineno(six.text_type(e)))
-                self.assertTrue(msg.endswith(src+":1:1: expected <block end>, but found ':'")
-                                or msg.endswith(src+":1:1: expected <block end>, but found u':'"))
+                self.assertTrue(msg.endswith(src+":2:1: expected <block end>, but found ':'")
+                                or msg.endswith(src+":2:1: expected <block end>, but found u':'"))
                 print("\n", e)
                 raise
@@ -88,9 +87,9 @@
                 assert msgs[1].endswith(
-                    src + ':13:5: Field `type` references unknown identifier '
+                    src + ':14:5: Field `type` references unknown identifier '
                     '`Filea`, tried file://%s#Filea' % (fullpath))
                 raise
